==> tarantool-2.8.2.80.tar.gz: tarantool-2.8.2.80/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/mempool.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/mempool.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/slab_arena.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/slab_arena.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/slab_cache.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/slab_cache.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/small.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/small.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/small_class.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/small_class.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/small_alloc.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/small_alloc.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "CORO_ASM"
  "DT_NAMESPACE=tnt_"
  "LUAJIT_SMART_STRINGS=1"
  "NDEBUG"
  "NVALGRIND"
  "NVALGRIND=1"
  "SLAB_MIN_ORDER0_SIZE=32768"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_CONSTANT_MACROS=1"
  "__STDC_FORMAT_MACROS=1"
  "__STDC_LIMIT_MACROS=1"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "src"
  "src/lib"
  "src/lib/small/include"
  "src/lib/small/third_party"
  "src/lib/core"
  "third_party"
  "third_party/zstd/lib"
  "third_party/zstd/lib/common"
  "third_party/xxHash"
  "third_party/luajit/src"
  "third_party/coro"
  "third_party/libyaml/include"
  "src/lib/msgpuck"
  "build/curl/dest/include"
  "third_party/decNumber"
  "third_party/libutil_freebsd"
  "src/lib/small/small/include"
  "src/lib/small/include/small"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> tarantool-2.8.2.83.tar.gz: tarantool-2.8.2.83/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/mempool.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/mempool.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/slab_arena.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/slab_arena.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/slab_cache.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/slab_cache.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/small.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/small.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/small/small_class.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/__/small/small_class.c.o"
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/small_alloc.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/small_alloc_32768.test.dir/small_alloc.c.o"
  )
set(CMAKE_C_COMPILER_ID "Clang")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "CORO_ASM"
  "DT_NAMESPACE=tnt_"
  "LUAJIT_SMART_STRINGS=1"
  "NDEBUG"
  "NVALGRIND"
  "NVALGRIND=1"
  "SLAB_MIN_ORDER0_SIZE=32768"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_CONSTANT_MACROS=1"
  "__STDC_FORMAT_MACROS=1"
  "__STDC_LIMIT_MACROS=1"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "src"
  "src/lib"
  "src/lib/small/include"
  "src/lib/small/third_party"
  "src/lib/core"
  "third_party"
  "third_party/zstd/lib"
  "third_party/zstd/lib/common"
  "third_party/xxHash"
  "third_party/luajit/src"
  "third_party/coro"
  "third_party/libyaml/include"
  "src/lib/msgpuck"
  "build/curl/dest/include"
  "third_party/decNumber"
  "third_party/libutil_freebsd"
  "src/lib/small/small/include"
  "src/lib/small/include/small"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
